/*
 * Copyright (c) 2016-2017 Contributors to the Eclipse Foundation
 *
 *  See the NOTICE file(s) distributed with this work for additional
 *  information regarding copyright ownership.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.eclipse.microprofile.jwt;

import java.security.Principal;

/**
 * A representation of a claim in a {@link JsonWebToken}
 *
 * @param <T>
 *            the expected type of the claim
 */
public interface ClaimValue<T> extends Principal {
    /**
     * Access the name of the claim.
     *
     * @return The name of the claim as seen in the JsonWebToken content
     */
    @Override
    String getName();

    /**
     * Access the value of the claim.
     *
     * @return the value of the claim.
     */
    T getValue();
}
